@@ -15,8 +15,8 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.cl_template import TemplateFormat
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_template import TemplateFormat
+from ..cl_lang import setLocalTranslate
 from collections import OrderedDict
 
 _ = lambda x: x
